==> mc-4.5.48.tar.gz: mc-4.5.48/lib/mc.hint.cs <==
Midnight Commander (c) 1995-1999, Free Software Foundation
Tip: C-x t vlo na pkazovou dku oznaen soubory.
Tip: C-x p vlo na pkazovou dku jmno aktulnho adrese.
Tip: K doplovn pouijte M-Tab (nebo Esc+Tab). Dvojitm zadn zskte seznam.
Tip: Pouitm M-p nebo M-n se pohybujete v historii pkaz.
Tip: Chcete zadat speciln znak(nap. tabeltor)? Pouijte Ctrl-Q a dan znak.
Tip: Nechcete ji vidt tipy? Vypnte je v Nastaven/Zobrazen/Dal nastaven.
Tip: Adrese vyberete pidnm lomtka na konec vzorku.
Tip: Pokud V terminl nezn nebo nem funkn klvesy, pouijte Esc+slo.
Tip: Domc strnka programu Midnight Commander je na http://www.gnome.org/mc/
Tip: Posledn verze programu Midnight Commander je na ftp://ftp.gnome.org/pub/GNOME/sources/mc
Tip: Zprvy o chybch poslejte na mc-bugs@nuclecu.unam.mx (anglicky).
Tip: Pomoc klvesy Tab zmnte aktuln panel.
Tip: Stiskem Enter na souboru .tar nebo .tar.gz si prohldnete obsah.
Tip: Existuje tak manulov strnka [mc(1)].
Tip: Pejete si klvesy stejn jako v lynxu? Nastavte to v Nastaven.
Tip: Makra uvozen % pracuj na pkazov dce.
Tip: Pomoc M-! mete spustit pkaz a prohldnout si vstup v okn.
Tip: Zobrazen v panelech me bt upraveno. Z 'man mc' se dozvte vce.
Tip: %D/%T se rozvine na soubory oznaen v druhm panelu.
Tip: Chcete opt v shell? Stisknte C-o. Do MC se vrtte opt pes C-o.
Tip: Nastavenm promnn CDPATH mete etit klvesnici.
Tip: Pokud chcete vidt soubory zanajc tekou, eknte to v Nastaven.
Tip: Chcete vidt zlohy svch soubor (kon ~). Pouijte Nastaven.
Tip: Mte opravdu mnoho pamti? Zkuste nastavit limit ve VFS na -1.
Tip: Doplovn funguje ve vstupnch dkch vech dialog. Pouijte M-Tab.
Tip: Na terminlech s pomalou odezvou skuste na parametr -s (mc -s).
Tip: S nalezenmi soubory mete pracovat. Stiknte tlatko Panelizace.
Tip: Pro opravdu sloit operace zkuste pkaz Pkaz/Extern panelizace.
Tip: Pokud chcete zmnit adres pi prci na pkoazov dce, zkuste M-c.
Poznmka: Pkazy shellu nefunguj, pokud nepracujete na lokln systmu soubor.
Tip: Smazan text obnovte C-y.
Tip: Pokud nkter klvesy nefunfuj, pouijte menu Nastaven/uen klves.
Tip: F13 (nebo Shift-F3) vyvol prohlen bez zpracovn obsahu souboru.
Tip: Pokud v xtermu nepracuj klvesy, zkuste soubory xterm.ad, .ti a .tcap.
Tip: Editor pro klvesu F4 urte pomoc promnn prosted EDITOR.
Tip: Extern prohle urte promnnou PAGER.
Tip: Vechny dosti o potvrzen mete zakzat v Nastaven/Potvrzovn.
Tip: K seznam asto pouvanch adres se mete dostat i pes C-\.
Tip: Na anonymn FTP se pipojte pomoc 'cd /#ftp:stroj.domena.cz'
Tip: MC m vestavn FTP protokol. Podvejte se do menu Lev/Ftp spojen.
Tip: M-t rychle mn formt zobrazen panel.
Tip: Pi FTP spojen mete zadat i jmno: 'cd /#ftp:jmeno@stroj.domena.cz'
Tip: RPM soubory si prohldnete stiskem Enter.
Tip: Pokud chcete oznait adres, pidejte '/' (lomtko).
Tip: Chcete-li pout my pro zkoprovn nebo vloen textu, stisknte Shift.
Tip: V seznamu adres mete mt i asto navtvovan ftp servery. Zkuste C-\.

==> mc-4.6.0-pre1.tar.gz: mc-4.6.0-pre1/lib/mc.hint.cs <==
Midnight Commander (c) 1995-2001, Free Software Foundation
Tip: C-x t vlo na pkazovou dku oznaen soubory.
Tip: C-x p vlo na pkazovou dku jmno aktulnho adrese.
Tip: K doplovn pouijte M-Tab (nebo Esc+Tab). Dvojitm zadn zskte seznam.
Tip: Pouitm M-p nebo M-n se pohybujete v historii pkaz.
Tip: Chcete zadat speciln znak(nap. tabeltor)? Pouijte Ctrl-Q a dan znak.
Tip: Nechcete ji vidt tipy? Vypnte je v Nastaven/Zobrazen/Dal nastaven.
Tip: Adrese vyberete pidnm lomtka na konec vzorku.
Tip: Pokud V terminl nezn nebo nem funkn klvesy, pouijte Esc+slo.
Tip: Domc strnka programu Midnight Commander je na http://www.gnome.org/mc/
Tip: Zprvy o chybch poslejte na mc-devel@gnome.org (anglicky).
Tip: Pomoc klvesy Tab zmnte aktuln panel.
Tip: Stiskem Enter na souboru .tar nebo .tar.gz si prohldnete obsah.
Tip: Existuje tak manulov strnka [mc(1)].
Tip: Pejete si klvesy stejn jako v lynxu? Nastavte to v Nastaven.
Tip: Makra uvozen % pracuj na pkazov dce.
Tip: Pomoc M-! mete spustit pkaz a prohldnout si vstup v okn.
Tip: Zobrazen v panelech me bt upraveno. Z 'man mc' se dozvte vce.
Tip: %D/%T se rozvine na soubory oznaen v druhm panelu.
Tip: Chcete opt v shell? Stisknte C-o. Do MC se vrtte opt pes C-o.
Tip: Nastavenm promnn CDPATH mete etit klvesnici.
Tip: Pokud chcete vidt soubory zanajc tekou, eknte to v Nastaven.
Tip: Chcete vidt zlohy svch soubor (kon ~). Pouijte Nastaven.
Tip: Mte opravdu mnoho pamti? Zkuste nastavit limit ve VFS na -1.
Tip: Doplovn funguje ve vstupnch dkch vech dialog. Pouijte M-Tab.
Tip: Na terminlech s pomalou odezvou skuste na parametr -s (mc -s).
Tip: S nalezenmi soubory mete pracovat. Stiknte tlatko Panelizace.
Tip: Pro opravdu sloit operace zkuste pkaz Pkaz/Extern panelizace.
Tip: Pokud chcete zmnit adres pi prci na pkoazov dce, zkuste M-c.
Poznmka: Pkazy shellu nefunguj, pokud nepracujete na lokln systmu soubor.
Tip: Smazan text obnovte C-y.
Tip: Pokud nkter klvesy nefunfuj, pouijte menu Nastaven/uen klves.
Tip: F13 (nebo Shift-F3) vyvol prohlen bez zpracovn obsahu souboru.
Tip: Pokud v xtermu nepracuj klvesy, zkuste soubory xterm.ad, .ti a .tcap.
Tip: Editor pro klvesu F4 urte pomoc promnn prosted EDITOR.
Tip: Extern prohle urte promnnou PAGER.
Tip: Vechny dosti o potvrzen mete zakzat v Nastaven/Potvrzovn.
Tip: K seznam asto pouvanch adres se mete dostat i pes C-\.
Tip: Na anonymn FTP se pipojte pomoc 'cd /#ftp:stroj.domena.cz'
Tip: MC m vestavn FTP protokol. Podvejte se do menu Lev/Ftp spojen.
Tip: M-t rychle mn formt zobrazen panel.
Tip: Pi FTP spojen mete zadat i jmno: 'cd /#ftp:jmeno@stroj.domena.cz'
Tip: RPM soubory si prohldnete stiskem Enter.
Tip: Pokud chcete oznait adres, pidejte '/' (lomtko).
Tip: Chcete-li pout my pro zkoprovn nebo vloen textu, stisknte Shift.
Tip: V seznamu adres mete mt i asto navtvovan ftp servery. Zkuste C-\.
